# coding: utf-8

from aio_client.base import RequestTypeEnum
from aio_client.base import _prepare_log
from aio_client.base import send_request
from aio_client.base.helpers import post_request
from aio_client.base.signals import get_data_done
from aio_client.base.signals import robust_sender

from .models import GetProviderReceipt
from .models import GetProviderRequest
from .models import PostProviderRequest


@robust_sender(get_data_done, sender=GetProviderRequest)
def provider_get_requests():
    """Получение всех заявок к РИС.

    :return: список словарей с параметрами ответа
    :rtype: list
    """
    request_log = _prepare_log(RequestTypeEnum.PR_GET)

    response = send_request(request_log)
    for message in response.json():
        message['request_id'] = request_log
        if (
                GetProviderRequest.objects.filter(
                    origin_message_id=message['origin_message_id']
                ).exists()
        ):
            continue
        GetProviderRequest.objects.create(**message)
    return response.json()


def provider_post_request(request_msg):
    """Передача ответа на заявки
    :param request_msg: объект класса PostProviderRequest
     c параметрами ответа
    :return: инстанс класса requests.models.Response
    """
    assert isinstance(request_msg, PostProviderRequest)
    return post_request(request_msg)


@robust_sender(get_data_done, sender=GetProviderReceipt)
def provider_get_receipt():
    """Получение ответа СМЭВ по всем отправленным заявкам
    :return dict словарь с параметрами ответа
    """
    request_log = _prepare_log(RequestTypeEnum.PR_GET_R)

    response = send_request(request_log)
    for message in response.json():
        message['request_id'] = request_log
        GetProviderReceipt.objects.create(**message)
    return response.json()
